@@ -81,7 +81,11 @@ class Engine(EnvironmentVariable, type=str):
         -------
         str
         """
-        from modin.utils import MIN_RAY_VERSION, MIN_DASK_VERSION
+        from modin.utils import (
+            MIN_RAY_VERSION,
+            MAX_RAY_VERSION_EXCLUSIVE,
+            MIN_DASK_VERSION,
+        )
 
         if IsDebug.get():
             return "Python"
@@ -91,9 +95,14 @@ class Engine(EnvironmentVariable, type=str):
         except ImportError:
             pass
         else:
-            if version.parse(ray.__version__) < MIN_RAY_VERSION:
+            if (
+                version.parse(ray.__version__) < MIN_RAY_VERSION
+                or version.parse(ray.__version__) >= MAX_RAY_VERSION_EXCLUSIVE
+            ):
                 raise ImportError(
-                    "Please `pip install modin[ray]` to install compatible Ray version (>={MIN_RAY_VERSION})."
+                    "Please `pip install modin[ray]` to install compatible Ray "
+                    + "version "
+                    + f"(>={MIN_RAY_VERSION},<{MAX_RAY_VERSION_EXCLUSIVE})."
                 )
             return "Ray"
         try:
@@ -108,7 +117,7 @@ class Engine(EnvironmentVariable, type=str):
                 or version.parse(distributed.__version__) < MIN_DASK_VERSION
             ):
                 raise ImportError(
-                    "Please `pip install modin[dask]` to install compatible Dask version (>={MIN_DASK_VERSION})."
+                    f"Please `pip install modin[dask]` to install compatible Dask version (>={MIN_DASK_VERSION})."
                 )
             return "Dask"
         try:
@@ -358,8 +367,99 @@ class BenchmarkMode(EnvironmentVariable, type=bool):
         super().put(value)
 
 
+class LogMode(EnvironmentVariable, type=ExactStr):
+    """Set ``LogMode`` value if users want to opt-in."""
+
+    varname = "MODIN_LOG_MODE"
+    choices = ("enable", "disable", "enable_api_only")
+    default = "disable"
+
+    @classmethod
+    def enable(cls):
+        """Enable all logging levels."""
+        cls.put("enable")
+
+    @classmethod
+    def disable(cls):
+        """Disable logging feature."""
+        cls.put("disable")
+
+    @classmethod
+    def enable_api_only(cls):
+        """Enable API level logging."""
+        cls.put("enable_api_only")
+
+
+class LogMemoryInterval(EnvironmentVariable, type=int):
+    """Interval (in seconds) to profile memory utilization for logging."""
+
+    varname = "MODIN_LOG_MEMORY_INTERVAL"
+    default = 5
+
+    @classmethod
+    def put(cls, value):
+        """
+        Set ``LogMemoryInterval`` with extra checks.
+
+        Parameters
+        ----------
+        value : int
+            Config value to set.
+        """
+        if value <= 0:
+            raise ValueError(f"Log memory Interval should be > 0, passed value {value}")
+        super().put(value)
+
+    @classmethod
+    def get(cls):
+        """
+        Get ``LogMemoryInterval`` with extra checks.
+
+        Returns
+        -------
+        int
+        """
+        log_memory_interval = super().get()
+        assert log_memory_interval > 0, "`LogMemoryInterval` should be > 0"
+        return log_memory_interval
+
+
+class LogFileSize(EnvironmentVariable, type=int):
+    """Max size of logs (in MBs) to store per Modin job."""
+
+    varname = "MODIN_LOG_FILE_SIZE"
+    default = 10
+
+    @classmethod
+    def put(cls, value):
+        """
+        Set ``LogFileSize`` with extra checks.
+
+        Parameters
+        ----------
+        value : int
+            Config value to set.
+        """
+        if value <= 0:
+            raise ValueError(f"Log file size should be > 0 MB, passed value {value}")
+        super().put(value)
+
+    @classmethod
+    def get(cls):
+        """
+        Get ``LogFileSize`` with extra checks.
+
+        Returns
+        -------
+        int
+        """
+        log_file_size = super().get()
+        assert log_file_size > 0, "`LogFileSize` should be > 0"
+        return log_file_size
+
+
 class PersistentPickle(EnvironmentVariable, type=bool):
-    """Wheather serialization should be persistent."""
+    """Whether serialization should be persistent."""
 
     varname = "MODIN_PERSISTENT_PICKLE"
     # When set to off, it allows faster serialization which is only
@@ -384,6 +484,7 @@ class OmnisciLaunchParameters(EnvironmentVariable, type=dict):
         "enable_lazy_fetch": 0,
         "null_div_by_zero": 1,
         "enable_watchdog": 0,
+        "enable_thrift_logs": 0,
     }
 
     @classmethod
@@ -445,6 +546,28 @@ class MinPartitionSize(EnvironmentVariable, type=int):
         return min_partition_size
 
 
+class TestReadFromSqlServer(EnvironmentVariable, type=bool):
+    """Set to true to test reading from SQL server."""
+
+    varname = "MODIN_TEST_READ_FROM_SQL_SERVER"
+    default = False
+
+
+class TestReadFromPostgres(EnvironmentVariable, type=bool):
+    """Set to true to test reading from Postgres."""
+
+    varname = "MODIN_TEST_READ_FROM_POSTGRES"
+    default = False
+
+
+class ReadSqlEngine(EnvironmentVariable, type=str):
+    """Engine to run `read_sql`."""
+
+    varname = "MODIN_READ_SQL_ENGINE"
+    default = "Pandas"
+    choices = ("Pandas", "Connectorx")
+
+
 def _check_vars():
     """
     Check validity of environment variables.
@@ -464,7 +587,7 @@ def _check_vars():
     if unknown:
         warnings.warn(
             f"Found unknown environment variable{'s' if len(unknown) > 1 else ''},"
-            f" please check {'their' if len(unknown) > 1 else 'its'} spelling: "
+            + f" please check {'their' if len(unknown) > 1 else 'its'} spelling: "
             + ", ".join(sorted(unknown))
         )
 
