@@ -53,6 +53,7 @@ from modin.core.io.file_dispatcher import OpenFile
 from modin.db_conn import ModinDatabaseConnection
 from modin.core.storage_formats.pandas.utils import split_result_of_axis_func_pandas
 from modin.error_message import ErrorMessage
+from modin.logging import LoggerMetaClass
 
 _doc_pandas_parser_class = """
 Class for handling {data_type} on the workers using pandas storage format.
@@ -73,7 +74,7 @@ Parameters
 Returns
 -------
 list
-    List with splitted parse results and it's metadata
+    List with split parse results and it's metadata
     (index, dtypes, etc.).
 """
 
@@ -123,13 +124,7 @@ def find_common_type_cat(types):
     """
     if all(isinstance(t, pandas.CategoricalDtype) for t in types):
         if all(t.ordered for t in types):
-            categories = np.unique([c for t in types for c in t.categories])[0]
-            if categories.ndim != 0:
-                categories = np.sort(categories)
-            else:
-                # Cannot use np.sort() on array with ndim == 0
-                # tolist() is called on scalar value and returns an int
-                categories = [categories.tolist()]
+            categories = np.sort(np.unique([c for t in types for c in t.categories]))
             return pandas.CategoricalDtype(
                 categories,
                 ordered=True,
@@ -142,7 +137,7 @@ def find_common_type_cat(types):
         return find_common_type(list(types))
 
 
-class PandasParser(object):
+class PandasParser(object, metaclass=LoggerMetaClass):
     """Base class for parser classes with pandas storage format."""
 
     @staticmethod
@@ -152,7 +147,7 @@ class PandasParser(object):
         num_splits = kwargs.pop("num_splits", None)
         start = kwargs.pop("start", None)
         end = kwargs.pop("end", None)
-        header_size = kwargs.pop("header_size", None)
+        header_size = kwargs.pop("header_size", 0)
         encoding = kwargs.get("encoding", None)
         callback = kwargs.pop("callback")
         if start is None or end is None:
@@ -240,8 +235,8 @@ class PandasParser(object):
             ErrorMessage.missmatch_with_pandas(
                 operation="read_*",
                 message="Data types of partitions are different! "
-                "Please refer to the troubleshooting section of the Modin documentation "
-                "to fix this issue",
+                + "Please refer to the troubleshooting section of the Modin documentation "
+                + "to fix this issue",
             )
 
             # concat all elements of `partitions_dtypes` and find common dtype
@@ -270,7 +265,7 @@ class PandasParser(object):
         BaseQueryCompiler or
         dict or
         pandas.io.parsers.TextFileReader
-            Object with imported data (or with reference to data) for furher
+            Object with imported data (or with reference to data) for further
             processing, object type depends on the child class `parse` function
             result type.
         """
@@ -386,6 +381,14 @@ class PandasPickleExperimentalParser(PandasParser):
         return _split_result_for_readers(1, num_splits, df) + [length, width]
 
 
+@doc(_doc_pandas_parser_class, data_type="custom text")
+class CustomTextExperimentalParser(PandasParser):
+    @staticmethod
+    @doc(_doc_parse_func, parameters=_doc_parse_parameters_common)
+    def parse(fname, **kwargs):
+        return PandasParser.generic_parse(fname, **kwargs)
+
+
 @doc(_doc_pandas_parser_class, data_type="tables with fixed-width formatted lines")
 class PandasFWFParser(PandasParser):
     @staticmethod
@@ -623,7 +626,7 @@ class PandasJSONParser(PandasParser):
             # This only happens when we are reading with only one worker (Default)
             return pandas.read_json(fname, **kwargs)
         if not pandas_df.columns.equals(columns):
-            raise NotImplementedError("Columns must be the same across all rows.")
+            raise ValueError("Columns must be the same across all rows.")
         partition_columns = pandas_df.columns
         return _split_result_for_readers(1, num_splits, pandas_df) + [
             len(pandas_df),
@@ -706,15 +709,36 @@ class PandasSQLParser(PandasParser):
 con : SQLAlchemy connectable, str, or sqlite3 connection
     Connection object to database.
 index_col : str or list of str
-    Column(s) to set as index(MultiIndex).""",
+    Column(s) to set as index(MultiIndex).
+read_sql_engine : str
+    Underlying engine ('pandas' or 'connectorx') used for fetching query result.""",
     )
-    def parse(sql, con, index_col, **kwargs):
+    def parse(sql, con, index_col, read_sql_engine, **kwargs):
+
+        enable_cx = False
+        if read_sql_engine == "Connectorx":
+            try:
+                import connectorx as cx
+
+                enable_cx = True
+            except ImportError:
+                warnings.warn(
+                    "Switch to 'pandas.read_sql' since 'connectorx' is not installed, please run 'pip install connectorx'."
+                )
+
         num_splits = kwargs.pop("num_splits", None)
         if isinstance(con, ModinDatabaseConnection):
-            con = con.get_connection()
+            con = con.get_string() if enable_cx else con.get_connection()
+
         if num_splits is None:
+            if enable_cx:
+                return cx.read_sql(con, sql, index_col=index_col)
             return pandas.read_sql(sql, con, index_col=index_col, **kwargs)
-        df = pandas.read_sql(sql, con, index_col=index_col, **kwargs)
+
+        if enable_cx:
+            df = cx.read_sql(con, sql, index_col=index_col)
+        else:
+            df = pandas.read_sql(sql, con, index_col=index_col, **kwargs)
         if index_col is None:
             index = len(df)
         else:
