@@ -30,6 +30,7 @@ from pandas._typing import CompressionOptions, StorageOptions
 from typing import Union, IO, AnyStr, Sequence, Dict, List, Optional, Any
 
 from modin.error_message import ErrorMessage
+from modin.logging import LoggerMetaClass, logger_decorator
 from .dataframe import DataFrame
 from modin.utils import _inherit_docstrings, Engine
 from . import _update_engine
@@ -72,6 +73,7 @@ def _read(**kwargs):
 
 
 @_inherit_docstrings(pandas.read_csv, apilink="pandas.read_csv")
+@logger_decorator("PANDAS-API", "read_csv", "info")
 def read_csv(
     filepath_or_buffer: "FilePath | ReadCsvBuffer[bytes] | ReadCsvBuffer[str]",
     sep=lib.no_default,
@@ -139,6 +141,7 @@ def read_csv(
 
 
 @_inherit_docstrings(pandas.read_table, apilink="pandas.read_table")
+@logger_decorator("PANDAS-API", "read_table", "info")
 def read_table(
     filepath_or_buffer: "FilePath | ReadCsvBuffer[bytes] | ReadCsvBuffer[str]",
     sep=lib.no_default,
@@ -208,6 +211,7 @@ def read_table(
 
 
 @_inherit_docstrings(pandas.read_parquet, apilink="pandas.read_parquet")
+@logger_decorator("PANDAS-API", "read_parquet", "info")
 def read_parquet(
     path,
     engine: str = "auto",
@@ -235,6 +239,7 @@ def read_parquet(
 
 
 @_inherit_docstrings(pandas.read_json, apilink="pandas.read_json")
+@logger_decorator("PANDAS-API", "read_json", "info")
 def read_json(
     path_or_buf=None,
     orient=None,
@@ -266,6 +271,7 @@ def read_json(
 
 
 @_inherit_docstrings(pandas.read_gbq, apilink="pandas.read_gbq")
+@logger_decorator("PANDAS-API", "read_gbq", "info")
 def read_gbq(
     query: str,
     project_id: Optional[str] = None,
@@ -294,6 +300,7 @@ def read_gbq(
 
 
 @_inherit_docstrings(pandas.read_html, apilink="pandas.read_html")
+@logger_decorator("PANDAS-API", "read_html", "info")
 def read_html(
     io,
     match=".+",
@@ -323,6 +330,7 @@ def read_html(
 
 
 @_inherit_docstrings(pandas.read_clipboard, apilink="pandas.read_clipboard")
+@logger_decorator("PANDAS-API", "read_clipboard", "info")
 def read_clipboard(sep=r"\s+", **kwargs):  # pragma: no cover  # noqa: PR01, RT01, D200
     """
     Read text from clipboard and pass to read_csv.
@@ -337,6 +345,7 @@ def read_clipboard(sep=r"\s+", **kwargs):  # pragma: no cover  # noqa: PR01, RT0
 
 
 @_inherit_docstrings(pandas.read_excel, apilink="pandas.read_excel")
+@logger_decorator("PANDAS-API", "read_excel", "info")
 def read_excel(
     io,
     sheet_name: "str | int | list[IntStrT] | None" = 0,
@@ -385,6 +394,7 @@ def read_excel(
 
 
 @_inherit_docstrings(pandas.read_hdf, apilink="pandas.read_hdf")
+@logger_decorator("PANDAS-API", "read_hdf", "info")
 def read_hdf(
     path_or_buf,
     key=None,
@@ -411,6 +421,7 @@ def read_hdf(
 
 
 @_inherit_docstrings(pandas.read_feather, apilink="pandas.read_feather")
+@logger_decorator("PANDAS-API", "read_feather", "info")
 def read_feather(
     path,
     columns=None,
@@ -429,6 +440,7 @@ def read_feather(
 
 
 @_inherit_docstrings(pandas.read_stata, apilink="pandas.read_stata")
+@logger_decorator("PANDAS-API", "read_stata", "info")
 def read_stata(
     filepath_or_buffer,
     convert_dates=True,
@@ -455,6 +467,7 @@ def read_stata(
 
 
 @_inherit_docstrings(pandas.read_sas, apilink="pandas.read_sas")
+@logger_decorator("PANDAS-API", "read_sas", "info")
 def read_sas(
     filepath_or_buffer,
     format=None,
@@ -475,6 +488,7 @@ def read_sas(
 
 
 @_inherit_docstrings(pandas.read_pickle, apilink="pandas.read_pickle")
+@logger_decorator("PANDAS-API", "read_pickle", "info")
 def read_pickle(
     filepath_or_buffer,
     compression: Optional[str] = "infer",
@@ -492,6 +506,7 @@ def read_pickle(
 
 
 @_inherit_docstrings(pandas.read_sql, apilink="pandas.read_sql")
+@logger_decorator("PANDAS-API", "read_sql", "info")
 def read_sql(
     sql,
     con,
@@ -520,6 +535,7 @@ def read_sql(
 
 
 @_inherit_docstrings(pandas.read_fwf, apilink="pandas.read_fwf")
+@logger_decorator("PANDAS-API", "read_fwf", "info")
 def read_fwf(
     filepath_or_buffer: Union[str, pathlib.Path, IO[AnyStr]],
     colspecs="infer",
@@ -550,6 +566,7 @@ def read_fwf(
 
 
 @_inherit_docstrings(pandas.read_sql_table, apilink="pandas.read_sql_table")
+@logger_decorator("PANDAS-API", "read_sql_table", "info")
 def read_sql_table(
     table_name,
     con,
@@ -572,6 +589,7 @@ def read_sql_table(
 
 
 @_inherit_docstrings(pandas.read_sql_query, apilink="pandas.read_sql_query")
+@logger_decorator("PANDAS-API", "read_sql_query", "info")
 def read_sql_query(
     sql,
     con,
@@ -594,6 +612,7 @@ def read_sql_query(
 
 
 @_inherit_docstrings(pandas.read_spss, apilink="pandas.read_spss")
+@logger_decorator("PANDAS-API", "read_spss", "info")
 def read_spss(
     path: Union[str, pathlib.Path],
     usecols: Union[Sequence[str], type(None)] = None,
@@ -610,16 +629,49 @@ def read_spss(
     )
 
 
-@_inherit_docstrings(pandas.to_pickle, apilink="pandas.to_pickle")
+# Adding docstring since pandas docs don't have web section for this function.
+@logger_decorator("PANDAS-API", "to_pickle", "info")
 def to_pickle(
     obj: Any,
     filepath_or_buffer,
     compression: CompressionOptions = "infer",
     protocol: int = pickle.HIGHEST_PROTOCOL,
     storage_options: StorageOptions = None,
-):  # noqa: PR01, RT01, D200
+):  # noqa: RT01
     """
     Pickle (serialize) object to file.
+
+    Parameters
+    ----------
+    obj : any object
+        Any python object.
+    filepath_or_buffer : str, path object, or file-like object
+        String, path object (implementing `os.PathLike[str]`), or file-like
+        object implementing a binary ``write()`` function.
+    compression : str or dict, default: 'infer'
+        For on-the-fly compression of the output data. If `infer` and `filepath_or_buffer`
+        path-like, then detect compression from the following extensions: '.gz',
+        '.bz2', '.zip', '.xz', or '.zst' (otherwise no compression). Set to
+        `None` for no compression. Can also be a dict with key `method` set
+        to one of {`zip`, `gzip`, `bz2`, `zstd`} and other
+        key-value pairs are forwarded to ``zipfile.ZipFile``, ``gzip.GzipFile``,
+        ``bz2.BZ2File``, or ``zstandard.ZstdDecompressor``, respectively. As an
+        example, the following could be passed for faster compression and to create
+        a reproducible gzip archive:
+        `compression={'method': 'gzip', 'compresslevel': 1, 'mtime': 1}`.
+    protocol : int, default: pickle.HIGHEST_PROTOCOL
+        Int which indicates which protocol should be used by the pickler,
+        default HIGHEST_PROTOCOL. The possible values for this parameter depend
+        on the version of Python. For Python 2.x, possible values are 0, 1, 2.
+        For Python>=3.0, 3 is a valid value. For Python >= 3.4, 4 is a valid value.
+        A negative value for the protocol parameter is equivalent to setting its value to
+        HIGHEST_PROTOCOL.
+    storage_options : dict, optional
+        Extra options that make sense for a particular storage connection, e.g.
+        host, port, username, password, etc. For HTTP(S) URLs the key-value pairs
+        are forwarded to ``urllib`` as header options. For other URLs (e.g.
+        starting with "s3://", and "gcs://") the key-value pairs are forwarded to
+        ``fsspec``. Please see ``fsspec`` and ``urllib`` for more details.
     """
     Engine.subscribe(_update_engine)
     from modin.core.execution.dispatching.factories.dispatcher import FactoryDispatcher
@@ -636,6 +688,7 @@ def to_pickle(
 
 
 @_inherit_docstrings(pandas.json_normalize, apilink="pandas.json_normalize")
+@logger_decorator("PANDAS-API", "json_normalize", "info")
 def json_normalize(
     data: Union[Dict, List[Dict]],
     record_path: Optional[Union[str, List]] = None,
@@ -659,6 +712,7 @@ def json_normalize(
 
 
 @_inherit_docstrings(pandas.read_orc, apilink="pandas.read_orc")
+@logger_decorator("PANDAS-API", "read_orc", "info")
 def read_orc(
     path, columns: Optional[List[str]] = None, **kwargs
 ) -> DataFrame:  # noqa: PR01, RT01, D200
@@ -671,6 +725,7 @@ def read_orc(
 
 
 @_inherit_docstrings(pandas.read_xml, apilink="pandas.read_xml")
+@logger_decorator("PANDAS-API", "read_xml", "info")
 def read_xml(
     path_or_buffer,
     xpath="./*",
@@ -706,8 +761,8 @@ def read_xml(
     )
 
 
-@_inherit_docstrings(pandas.HDFStore, apilink="pandas.HDFStore")
-class HDFStore(pandas.HDFStore):  # noqa: PR01, D200
+@_inherit_docstrings(pandas.HDFStore)
+class HDFStore(pandas.HDFStore, metaclass=LoggerMetaClass):  # noqa: PR01, D200
     """
     Dict-like IO interface for storing pandas objects in PyTables.
     """
@@ -763,8 +818,8 @@ class HDFStore(pandas.HDFStore):  # noqa: PR01, D200
         return method
 
 
-@_inherit_docstrings(pandas.ExcelFile, apilink="pandas.ExcelFile")
-class ExcelFile(pandas.ExcelFile):  # noqa: PR01, D200
+@_inherit_docstrings(pandas.ExcelFile)
+class ExcelFile(pandas.ExcelFile, metaclass=LoggerMetaClass):  # noqa: PR01, D200
     """
     Class for parsing tabular excel sheets into DataFrame objects.
     """
